@@ -1,7 +1,7 @@
 #!/usr/bin/python
 #
 # Python client for checking periodically for posted actions
-# on the Red Hat Network servers.
+# on the Spacewalk servers.
 #
 # Copyright (c) 2000--2012 Red Hat, Inc.
 #
@@ -39,6 +39,10 @@ _ = t.ugettext
 from OpenSSL import SSL
 sys.path.append("/usr/share/rhn/")
 
+# disable sgmlop module
+# it breaks rhn_check when loaded during xmlrpclib import
+sys.modules['sgmlop'] = None
+
 from up2date_client import getMethod
 from up2date_client import up2dateErrors
 from up2date_client import up2dateAuth
@@ -51,12 +55,13 @@ from up2date_client import rhncli, rhnserver
 
 from rhn import rhnLockfile
 import xmlrpclib
+del sys.modules['sgmlop']
 
 cfg = config.initUp2dateConfig()
 log = up2dateLog.initLog()
 
 # action version we understand
-ACTION_VERSION = 2 
+ACTION_VERSION = 2
 
 # lock file to check if we're disabled at the server's request
 DISABLE_FILE = "/etc/sysconfig/rhn/disable"
@@ -70,7 +75,7 @@ class CheckCli(rhncli.RhnCli):
     def __init__(self):
         super(CheckCli, self).__init__()
 
-        self.rhns_ca_cert = cfg['sslCACert'] 
+        self.rhns_ca_cert = cfg['sslCACert']
         self.server = None
 
     def main(self):
@@ -90,13 +95,6 @@ class CheckCli(rhncli.RhnCli):
         if s.capabilities.hasCapability('staging_content', 1) and cfg['stagingContent'] != 0:
              self.__check_future_actions()
 
-        if s.capabilities.hasCapability('abrt.handle') and \
-            'abrt.check' in clientCaps.caps.keys():
-            log.log_debug("abrt support found")
-            version = s.capabilities.parseCapVersion(
-                s.capabilities.data['abrt.handle']['version'])[0]
-            self.__check_abrt(version)
-
         sys.exit(0)
 
     def __get_action(self, status_report):
@@ -181,13 +179,13 @@ class CheckCli(rhncli.RhnCli):
     def __run_remote_actions(self):
         # the list of caps the client needs
         caps = capabilities.Capabilities()
-        
+
         status_report = CheckCli.__build_status_report()
 
         action = self.__get_action(status_report)
         while action != "" and action != {}:
             self.__verify_server_capabilities(caps)
-               
+
             if self.is_valid_action(action):
                 try:
                     up2dateAuth.updateLoginInfo()
@@ -202,17 +200,17 @@ class CheckCli(rhncli.RhnCli):
         response_headers = self.server.get_response_headers()
         caps.populate(response_headers)
         # do we actually want to validte here?
-        try:        
+        try:
             caps.validate()
         except up2dateErrors.ServerCapabilityError, e:
             print e
             sys.exit(1)
- 
+
     def __parse_action_data(self, action):
         """ Parse action data and returns (method, params) """
         data = action['action']
         parser, decoder = xmlrpclib.getparser()
-        parser.feed(data)
+        parser.feed(data.encode("utf-8"))
         parser.close()
         params = decoder.close()
         method = decoder.getmethodname()
@@ -223,7 +221,7 @@ class CheckCli(rhncli.RhnCli):
 
         # get a new server object with fresh headers
         self.server = CheckCli.__get_server()
-        
+
         try:
             ret = self.server.queue.submit(up2dateAuth.getSystemId(),
                                       action_id, status, message, data)
@@ -243,15 +241,15 @@ class CheckCli(rhncli.RhnCli):
         except socket.error:
             print "Could not submit to %s.\n"\
                   "Possible networking problem?" % str(self.server)
-            sys.exit(-1)                
+            sys.exit(-1)
         return ret
- 
+
     def handle_action(self, action, cache_only=None):
         """ Wrapper handler for the action we're asked to do. """
         log.log_debug("handle_action", action)
         log.log_debug("handle_action actionid = %s, version = %s" % (
             action['id'], action['version']))
-            
+
         (method, params) = self.__parse_action_data(action)
         (status, message, data) = CheckCli.__run_action(method, params, {'cache_only': cache_only})
         ret = 0
@@ -263,7 +261,7 @@ class CheckCli(rhncli.RhnCli):
 
     def is_valid_action(self, action):
         log.log_debug("check_action", action)
-            
+
         # be very paranoid of what we get back
         if type(action) != type({}):
             print "Got unparseable action response from server"
@@ -286,37 +284,6 @@ class CheckCli(rhncli.RhnCli):
             return False
         return True
 
-    def __check_abrt(self, version):
-        ret = CheckCli.__run_action('abrt.check',
-            ('version=%d' % version,))
-        log.log_debug("check_abrt status: %s" % (ret,))
-        (status, message, data) = ret
-
-        self.server = CheckCli.__get_server()
-
-        try:
-            ret = self.server.abrt.handle(up2dateAuth.getSystemId(),
-                version, status, message, data)
-            log.log_debug("abrt.handle successful")
-        except xmlrpclib.Fault, f:
-            print "Could not submit results to server %s" % self.server
-            print "Error code: %d%s" % (f.faultCode, f.faultString)
-            sys.exit(-1)
-        # XXX: what if no SSL in socket?
-        except socket.sslerror:
-            print "ERROR: SSL handshake to %s failed" % self.server
-            print """
-            This could signal that you are *NOT* talking to a server
-            whose certificate was signed by a Certificate Authority
-            listed in the %s file or that the
-            RHNS-CA-CERT file is invalid.""" % self.rhns_ca_cert
-            sys.exit(-1)
-        except socket.error:
-            print "Could not submit to %s.\n"\
-                  "Possible networking problem?" % str(self.server)
-            sys.exit(-1)
-        return ret
-
     @staticmethod
     def __get_server():
         """ Initialize a server connection and set up capability info. """
@@ -353,6 +320,10 @@ class CheckCli(rhncli.RhnCli):
             except:
                 pass
 
+        # We need to fit into xmlrpc's integer limits
+        if status_report['uptime'][1] > 2L**31-1:
+            status_report['uptime'][1] = -1
+
         return status_report
 
     @staticmethod
@@ -376,7 +347,7 @@ class CheckCli(rhncli.RhnCli):
 
         method = getMethod.getMethod(method, "/usr/share/rhn/", "actions")
         retval = method(*params, **kwargs)
-    
+
         return retval
 
     @staticmethod
@@ -415,7 +386,7 @@ class CheckCli(rhncli.RhnCli):
     def __check_instance_lock():
         lock = None
         try:
-            lock = rhnLockfile.Lockfile('/var/run/rhn_check.pid')        
+            lock = rhnLockfile.Lockfile('/var/run/rhn_check.pid')
         except rhnLockfile.LockfileLockedException, e:
             sys.stderr.write(rhncli.utf8_encode(_("Attempting to run more than one instance of rhn_check. Exiting.\n")))
             sys.exit(0)
