@@ -1,11 +1,10 @@
 # This file is a portion of the Red Hat Update Agent
-# Copyright (c) 1999--2012 Red Hat, Inc.  Distributed under GPL
+# Copyright (c) 1999--2014 Red Hat, Inc.  Distributed under GPL
 #
 # Authors:
 #       Cristian Gafton <gafton@redhat.com>
 #       Adrian Likins   <alikins@redhat.com>
 #
-# $Id$
 """
 This module includes the Config and Up2date Config classes use by the
 up2date agent to hold config info.
@@ -13,6 +12,7 @@ up2date agent to hold config info.
 
 import os
 import sys
+import locale
 from urlparse import urlsplit, urlunsplit
 from rhn.connections import idn_ascii_to_pune, idn_pune_to_unicode
 
@@ -114,7 +114,7 @@ class ConfigFile:
                 # possibly split value into a list
                 values = value.split(";")
                 if key in ['proxyUser', 'proxyPassword']:
-                    value = str(value)
+                    value = str(value.encode(locale.getpreferredencoding()))
                 elif len(values) == 1:
                     try:
                         value = int(value)
@@ -125,7 +125,7 @@ class ConfigFile:
                 else:
                     # there could be whitespace between the values on
                     # one line, let's strip it out
-                    value = [val.strip() for val in values[:-1]]
+                    value = [val.strip() for val in values if val.strip() ]
 
             # now insert the (comment, value) in the dictionary
             newval = (comment, value)
@@ -329,6 +329,11 @@ def setServerURL(serverURL):
     cfg = initUp2dateConfig()
     cfg.set('serverURL', serverURL)
 
+def setSSLCACert(sslCACert):
+    """ Set sslCACert in config """
+    cfg = initUp2dateConfig()
+    cfg.set('sslCACert', sslCACert)
+
 
 def initUp2dateConfig(cfg_file = "/etc/sysconfig/rhn/up2date"):
     """This function is the right way to get at the up2date config."""
