@@ -15,7 +15,7 @@ _ = t.ugettext
 # FIXME: After Debian bug 187019 is resolved
 def verifyPackages(packages):
     cache = apt.Cache()
-    missing_packages = []                                                                            
+    missing_packages = []
     for package in packages:
         pkg = cache[package[0]]
         if pkg == None or not pkg.is_installed:
@@ -28,22 +28,25 @@ def parseVRE(version):
     release = '0'
     if version.find(':') != -1:
         epoch, version = version.split(':')
-    if version.find('-') != -1: 
+    if version.find('-') != -1:
         tmp = version.split('-')
         version = '-'.join(tmp[:-1])
         release = tmp[-1]
     return version, release, epoch
 
-def installTime(pkg_name):
-    path = '/var/lib/dpkg/info/%s.list' % pkg_name
-    if os.path.isfile(path):
-       return os.path.getmtime(path)
-    else:
-       return None
+def installTime(pkg_name, pkg_arch):
+    dir = '/var/lib/dpkg/info'
+    files = [ '%s.list' % pkg_name,
+              '%s:%s.list' % (pkg_name, pkg_arch) ]
+    for f in files:
+        path = os.path.join(dir,f)
+        if os.path.isfile(path):
+            return os.path.getmtime(path)
+    return None
 
 #FIXME: Using Apt cache might not be an ultimate solution.
 # It could be better to parse /var/lib/dpkg/status manually.
-# Apt cache might not contain all the packages. 
+# Apt cache might not contain all the packages.
 def getInstalledPackageList(msgCallback = None, progressCallback = None,
                             getArch=None, getInfo = None):
     """ Return list of packages. Package is dict with following keys:
@@ -70,7 +73,7 @@ def getInstalledPackageList(msgCallback = None, progressCallback = None,
             'version': version,
             'release': release,
             'arch': pkg.installed.architecture + '-deb',
-            'installtime': installTime(pkg.name)
+            'installtime': installTime(pkg.name, pkg.installed.architecture)
             }
         pkg_list.append(package)
 
