@@ -1,5 +1,5 @@
 #
-# Copyright (c) 1999--2012 Red Hat, Inc.
+# Copyright (c) 1999--2014 Red Hat, Inc.
 #
 # This software is licensed to you under the GNU General Public License,
 # version 2 (GPLv2). There is NO WARRANTY for this software, express or
@@ -21,6 +21,7 @@ import re
 import os
 import sys
 import config
+import rhnserver
 
 try:
     import ethtool
@@ -50,6 +51,13 @@ try:
 except ImportError:
     locale = None
 
+sys.path.append("/usr/share/rhsm")
+try:
+    from subscription_manager.hwprobe import Hardware as SubManHardware
+    subscription_manager_available = True
+except ImportError:
+    subscription_manager_available = False
+
 # this does not change, we can cache it
 _dmi_data           = None
 _dmi_not_available  = 0
@@ -140,10 +148,10 @@ def read_installinfo():
             continue
         strippedstring = vals[0].strip()
         vals[0] = strippedstring
-        
+
         installdict[vals[0]] = ''.join(vals[1:]).strip()
     return installdict
-    
+
 def cpu_count():
     """ returns number of CPU in system
 
@@ -157,6 +165,60 @@ def cpu_count():
     re_cpu = re.compile(r"^cpu[0-9]+$")
     return len([i for i in cpu_dir if re_cpu.match(i)])
 
+# get the number of sockets available on this machine
+def __get_number_sockets():
+    try:
+        if subscription_manager_available:
+            return SubManHardware().getCpuInfo()['cpu.cpu_socket(s)']
+    except:
+        pass # something went wrong, let's figure it out ourselves
+
+    number_sockets = 0
+    # Try lscpu command if available
+    if os.access("/usr/bin/lscpu", os.X_OK):
+        try:
+            lines = os.popen("/usr/bin/lscpu -p").readlines()
+            max_socket_index = -1
+            for line in lines:
+                if line.startswith('#'):
+                    continue
+                # get the socket index from the output
+                socket_index = int(line.split(',')[2])
+                if socket_index > max_socket_index:
+                    max_socket_index = socket_index
+            if max_socket_index > -1:
+                return 1 + max_socket_index
+        except:
+            pass
+
+    # Next try parsing /proc/cpuinfo
+    if os.access("/proc/cpuinfo", os.R_OK):
+        try:
+            lines = open("/proc/cpuinfo", 'r').readlines()
+            socket_ids = set()
+            for line in lines:
+                if 'physical id' in line:
+                    socket_index = int(line.split(':')[1].strip())
+                    socket_ids.add(socket_index)
+            if len(socket_ids) > 0:
+                return len(socket_ids)
+        except:
+            pass
+
+    # Next try dmidecode
+    if os.access("/usr/sbin/dmidecode", os.X_OK):
+        try:
+            lines = os.popen("/usr/sbin/dmidecode -t processor").readlines()
+            count = 0
+            for line in lines:
+                if 'Processor Information' in line:
+                    count += 1
+            if count > 0:
+                return count
+        except:
+            pass
+
+    return None
 
 # This has got to be one of the ugliest fucntions alive
 def read_cpuinfo():
@@ -206,7 +268,7 @@ def read_cpuinfo():
     # class, desc (required to identify the hardware device)
     # count, type, model, model_number, model_ver, model_rev
     # bogomips, platform, speed, cache
-    
+
     hwdict = { 'class': "CPU",
                "desc" : "Processor",
                }
@@ -218,7 +280,7 @@ def read_cpuinfo():
             hwdict['platform'] = 'x86_64'
         else:
             hwdict['platform'] = "i386"
-            
+
         hwdict['count']         = count
         hwdict['type']          = get_entry(tmpdict, 'vendor_id')
         hwdict['model']         = get_entry(tmpdict, 'model name')
@@ -283,18 +345,18 @@ def read_cpuinfo():
         hwdict['model'] = get_entry(tmpdict, "cpu")
         hwdict['model_ver'] = get_entry(tmpdict, 'revision')
         hwdict['bogomips'] = get_entry(tmpdict, 'bogomips')
-        hwdict['vendor'] = get_entry(tmpdict, 'machine')
+        hwdict['type'] = get_entry(tmpdict, 'machine')
         # strings are postpended with "mhz"
         mhz_speed = get_entry(tmpdict, 'clock')[:-3]
         try:
             hwdict['speed'] = int(round(float(mhz_speed)) - 1)
         except ValueError:
             hwdict['speed'] = -1
-         
+
     elif uname in ['s390', 's390x']:
         tmpdict = {}
         for cpu in cpulist.split("\n"):
-            vals = cpu.split(cpu, ": ")
+            vals = cpu.split(": ")
             if len(vals) != 2:
                 continue
             tmpdict[vals[0].strip()] = vals[1].strip()
@@ -311,7 +373,7 @@ def read_cpuinfo():
         hwdict['other']         = get_entry(tmpdict, 'features')
         hwdict['speed']         = 0
 
-        
+
     else:
         # XXX: expand me. Be nice to others
         hwdict['platform']      = uname
@@ -337,7 +399,18 @@ def read_cpuinfo():
         else:
             if hwdict["count"] == 0: # we have at least one
                 hwdict["count"] = 1
-        
+
+    # Network communication doesn't really belong in here. Sadly though
+    # this is the only single place we can put this check. If it's not
+    # here then it would need to be in five or six other places, which
+    # is not good from a DRY and quality-assurance perspective.
+    s = rhnserver.RhnServer()
+    if s.capabilities.hasCapability('cpu_sockets'):
+        # If we know it add in the number of sockets
+        number_sockets = __get_number_sockets()
+        if number_sockets:
+            hwdict['socket_count'] = number_sockets
+
     # This whole things hurts a lot.
     return hwdict
 
@@ -386,10 +459,10 @@ def read_memory_2_6():
         #print blobs
         value = blobs[1].strip()
         meminfo_dict[key] = value
-        
+
     memdict = {}
     memdict["class"] = "MEMORY"
-    
+
     total_str = meminfo_dict['MemTotal']
     blips = total_str.split(" ")
     total_k = long(blips[0])
@@ -449,13 +522,21 @@ def findHostByRoute():
                 s.close()
                 continue
             s.close()
-        
-    # Override hostname with the one in /etc/sysconfig/network 
+
+    # Override hostname with the value from /etc/hostname
+    if os.path.isfile("/etc/hostname") and os.access("/etc/hostname", os.R_OK):
+        hostnameinfo = open("/etc/hostname", "r").readlines()
+
+        for info in hostnameinfo:
+            if not len(info):
+                continue
+            hostname = info.strip()
+
+    # Override hostname with the one in /etc/sysconfig/network
     # for bz# 457953
-    
-    if os.access("/etc/sysconfig/network", os.R_OK):
+    elif os.path.isfile("/etc/sysconfig/network") and os.access("/etc/sysconfig/network", os.R_OK):
         networkinfo = open("/etc/sysconfig/network", "r").readlines()
-	
+
         for info in networkinfo:
             if not len(info):
                 continue
@@ -467,7 +548,7 @@ def findHostByRoute():
             if vals[0] == "HOSTNAME":
                 hostname = ''.join(vals[1:]).strip()
                 break
-        
+
     if hostname == None or hostname == 'localhost.localdomain':
         hostname = "unknown"
     return hostname, intf, intf6
@@ -492,7 +573,7 @@ def get_slave_hwaddr(master, slave):
 
     bonding.close()
     return hwaddr
-    
+
 def read_network():
     netdict = {}
     netdict['class'] = "NETINFO"
@@ -501,6 +582,8 @@ def read_network():
 
     if netdict['hostname'] == "unknown":
         netdict['hostname'] = gethostname()
+        if "." not in netdict['hostname']:
+            netdict['hostname'] = socket.getfqdn()
 
     if netdict['ipaddr'] is None:
         try:
@@ -540,7 +623,7 @@ def read_network_interfaces():
             hwaddr = ethtool.get_hwaddr(interface)
         except:
             hwaddr = ""
-            
+
         # slave devices can have their hwaddr changed
         try:
             master = os.readlink('/sys/class/net/%s/master' % interface)
@@ -596,25 +679,25 @@ def read_network_interfaces():
     return intDict
 
 
-# Read DMI information via hal.    
+# Read DMI information via hal.
 def read_dmi():
     dmidict = {}
-    dmidict["class"] = "DMI" 
+    dmidict["class"] = "DMI"
 
     # Try to obtain DMI info if architecture is i386, x86_64 or ia64
     uname = os.uname()[4].lower()
     if not (uname[0] == "i"  and  uname[-2:] == "86") and not (uname == "x86_64"):
         return dmidict
 
-    # System Information 
+    # System Information
     vendor = dmi_vendor()
     if vendor:
         dmidict["vendor"] = vendor
-        
+
     product = get_dmi_data('/dmidecode/SystemInfo/ProductName')
     if product:
         dmidict["product"] = product
-        
+
     version = get_dmi_data('/dmidecode/SystemInfo/Version')
     if version:
         system = product + " " + version
@@ -623,7 +706,7 @@ def read_dmi():
     # BaseBoard Information
     dmidict["board"] = get_dmi_data('/dmidecode/BaseBoardInfo/Manufacturer')
 
-    # Bios Information    
+    # Bios Information
     vendor = get_dmi_data('/dmidecode/BIOSinfo/Vendor')
     if vendor:
         dmidict["bios_vendor"] = vendor
@@ -639,27 +722,27 @@ def read_dmi():
     chassis_serial = get_dmi_data('/dmidecode/ChassisInfo/SerialNumber')
     chassis_tag = get_dmi_data('/dmidecode/ChassisInfo/AssetTag')
     board_serial = get_dmi_data('/dmidecode/BaseBoardInfo/SerialNumber')
-    
+
     system_serial = get_dmi_data('/dmidecode/SystemInfo/SerialNumber')
-    
+
     dmidict["asset"] = "(%s: %s) (%s: %s) (%s: %s) (%s: %s)" % ("chassis", chassis_serial,
                                                      "chassis", chassis_tag,
                                                      "board", board_serial,
                                                      "system", system_serial)
-    
-    # Clean up empty entries    
+
+    # Clean up empty entries
     for k in dmidict.keys()[:]:
         if dmidict[k] is None:
             del dmidict[k]
             # Finished
-            
+
     return dmidict
 
 def get_hal_system_and_smbios():
     try:
         if using_gudev:
             props = get_computer_info()
-        else: 
+        else:
             computer = get_hal_computer()
             props = computer.GetAllProperties()
     except Exception, e:
@@ -706,7 +789,7 @@ def Hardware():
         hal_status, dbus_status = check_hal_dbus_status()
         hwdaemon = 1
         if hal_status or dbus_status:
-            # if status != 0 haldaemon or messagebus service not running. 
+            # if status != 0 haldaemon or messagebus service not running.
             # set flag and dont try probing hardware and DMI info
             # and warn the user.
             log = up2dateLog.initLog()
@@ -718,14 +801,14 @@ def Hardware():
         if hwdaemon:
             try:
                 ret = read_hal()
-                if ret: 
+                if ret:
                     allhw = ret
             except:
                 # bz253596 : Logging Dbus Error messages instead of printing on stdout
                 log = up2dateLog.initLog()
                 msg = "Error reading hardware information: %s\n" % (sys.exc_type)
                 log.log_me(msg)
-        
+
     # all others return individual arrays
 
     # cpu info
@@ -734,26 +817,26 @@ def Hardware():
         if ret: allhw.append(ret)
     except:
         print _("Error reading cpu information:"), sys.exc_type
-        
+
     # memory size info
     try:
         ret = read_memory()
         if ret: allhw.append(ret)
     except:
         print _("Error reading system memory information:"), sys.exc_type
-        
+
     cfg = config.initUp2dateConfig()
     if not cfg["skipNetwork"]:
         # minimal networking info
         try:
             ret = read_network()
-            if ret: 
+            if ret:
                 allhw.append(ret)
         except:
             print _("Error reading networking information:"), sys.exc_type
     # dont like catchall exceptions but theres not
     # really anything useful we could do at this point
-    # and its been trouble prone enough 
+    # and its been trouble prone enough
 
     # minimal DMI info
     try:
@@ -765,7 +848,7 @@ def Hardware():
         log = up2dateLog.initLog()
         msg = "Error reading DMI information: %s\n" % (sys.exc_type)
         log.log_me(msg)
-        
+
     try:
         ret = read_installinfo()
         if ret:
@@ -780,7 +863,7 @@ def Hardware():
                 allhw.append(ret)
         except:
             print _("Error reading network interface information:"), sys.exc_type
-    
+
     # all Done.
     return allhw
 
