@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # String constants for the RHN Register TUI/GUI.
-# Copyright (c) 2000--2012 Red Hat, Inc.
+# Copyright (c) 2000--2014 Red Hat, Inc.
 #
 # Author:
 #       James Slagle <jslagle@redhat.com>
@@ -11,10 +11,22 @@ import gettext
 t = gettext.translation('rhn-client-tools', fallback=True)
 _ = t.ugettext
 
-COPYRIGHT_TEXT        = _(u"Copyright © 2006--2010 Red Hat, Inc. All rights reserved.")
+COPYRIGHT_TEXT        = _(u"Copyright © 2006--2014 Red Hat, Inc. All rights reserved.")
+
+# Satellite URL Window
+SATELLITE_URL_WINDOW  = _("Enter your Red Hat Satellite URL.")
+SATELLITE_URL_TEXT    = _("Please enter the location of your Red Hat Satellite "
+                          "server and of its SSL "
+                          "certificate. The SSL certificate is only required "
+                          "if you will be connecting over https (recommended).")
+SATELLITE_URL_PROMPT  = _("Satellite URL:")
+SATELLITE_URL_PROMPT2 = _("SSL certificate:")
+SATELLITE_REQUIRED    = _("You must enter a valid Satellite URL.")
+SSL_REQUIRED          = _("If you are using https you must enter the location "
+                          "of a valid SSL certificate.")
 
 # Connect Window
-CONNECT_WINDOW        = _("Attempting to contact the Red Hat Network server.")
+CONNECT_WINDOW        = _("Attempting to contact the Spacewalk server.")
 CONNECT_WINDOW_TEXT   = _("We are attempting to contact the Red Hat "
                           "Network server at %s.")
 CONNECT_WINDOW_TEXT2  = _("A proxy was specified at %s.")
@@ -23,20 +35,20 @@ CONNECT_WINDOW_TEXT2  = _("A proxy was specified at %s.")
 START_REGISTER_WINDOW = _("System Registration")
 START_REGISTER_TEXT   = _("This assistant will guide you through "
                           "connecting your system to "
-                          "Red Hat Network (RHN) to receive software "
+                          "Red Hat Satellite to receive software "
                           "updates, including "
                           "security updates, to keep your system supported "
                           "and compliant.  "
                           "You will need the following at this time:\n\n"
                           " * A network connection\n"
                           " * Your Red Hat Login & password\n"
-                          " * The location of a Red Hat Network Satellite "
-                          "or Proxy (optional)\n\n")
+                          " * The location of a Red Hat Satellite "
+                          "or Proxy\n\n")
 
 # Why Register Window
 WHY_REGISTER          = _("Why Should I Connect to RHN? ...")
 WHY_REGISTER_WINDOW   = _("Why Register")
-WHY_REGISTER_TEXT     = _("Connecting your system to Red Hat Network allows you to take full "
+WHY_REGISTER_TEXT     = _("Connecting your system to Red Hat Satellite allows you to take full "
                           "advantage of the benefits of a paid subscription, including:")
 WHY_REGISTER_SEC      = _("Security & Updates:")
 WHY_REGISTER_DLD      = _("Downloads & Upgrades:")
@@ -57,10 +69,10 @@ BACK_REGISTER         = _("Take me back to the registration")
 
 # Confirm Quit Window
 CONFIRM_QUIT           = _("Software Update Not Set Up")
-CONFIRM_QUIT_SURE       = _("Are you sure you don't want to connect your system to Red Hat Network? "
+CONFIRM_QUIT_SURE       = _("Are you sure you don't want to connect your system to Red Hat Satellite? "
                            "You'll miss out on the benefits of a Red Hat Enterprise Linux subscription:\n")
 CONFIRM_QUIT_WILLNOT       = _("You will not be able to take advantage of these subscription privileges without connecting "
-                           "your system to Red Hat Network.\n")
+                           "your system to Red Hat Satellite.\n")
 CONTINUE_REGISTERING   = _("Take me back to the setup process.")
 REGISTER_LATER2        = _("I'll register later.")
 
@@ -91,7 +103,7 @@ CONFIRM_OS_ALL               = _("Your system will be subscribed to the base"
 HARDWARE_WINDOW = _("Create Profile - Hardware")
 HARDWARE_WINDOW_DESC1 = _("A Profile Name is a descriptive name that"
                           " you choose to identify this System Profile"
-                          " on the Red Hat Network web pages. Optionally,"
+                          " on the Red Hat Satellite web pages. Optionally,"
                           " include a computer serial or identification number.")
 HARDWARE_WINDOW_DESC2 = _("Additional hardware information including PCI"
                           " devices, disk sizes and mount points will be"
@@ -117,42 +129,40 @@ SYSTEM_ALREADY_SETUP = _("System Already Registered")
 SYSTEM_ALREADY_REGISTERED = _("It appears this system has already been set up for software updates:")
 SYSTEM_ALREADY_REGISTERED_CONT = _("Are you sure you would like to continue?")
 
-RHSM_SYSTEM_ALREADY_REGISTERED = _("This system has already been registered with RHN"
-				" using RHN certficate-based technology.\n\n"
-				"The tool you are using is attempting to re-register "
-				"using RHN Satellite or RHN Proxy technology. Red Hat recommends "
-				"(except in a few cases) that customers only register with RHN once.\n\n"
-				"To learn more about RHN registration and technologies please consult this"
+RHSM_SYSTEM_ALREADY_REGISTERED = _("This system has already been registered using Red Hat Subscription Management.\n\n"
+				"Your system is being registered again using Red Hat Satellite"
+				" or Red Hat Satellite Proxy technology. Red Hat recommends that customers only register once.\n\n"
+				"To learn more about RHN Classic/Red Hat Satellite registration and technologies please consult this"
 				" Knowledge Base Article: https://access.redhat.com/kb/docs/DOC-45563")
 
 # Send Window
-SEND_WINDOW      = _("Send Profile Information to Red Hat Network")
+SEND_WINDOW      = _("Send Profile Information to Red Hat Satellite")
 SEND_WINDOW_DESC = _("We are finished collecting information for the System Profile.\n\n"
-                     "Press \"Next\" to send this System Profile to Red Hat Network.  "
+                     "Press \"Next\" to send this System Profile to Red Hat Satellite.  "
                      "Click \"Cancel\" and no information will be sent.  "
                      "You can run the registration program later by "
                      "typing `rhn_register` at the command line.")
 
 # Sending Window
-SENDING_WINDOW = _("Sending Profile to Red Hat Network")
+SENDING_WINDOW = _("Sending Profile to Red Hat Satellite")
 
 # Finish Window
 FINISH_WINDOW           = _("Updates Configured")
 FINISH_WINDOW_TEXT_TUI  = _("You may now run 'yum update' from this system's "
                             "command line to get the latest "
-                            "software updates from Red Hat Network. You will need to run this "
+                            "software updates from Red Hat Satellite. You will need to run this "
                             "periodically to "
                             "get the latest updates. Alternatively, you may configure this "
                             "system for automatic software updates (also known as 'auto errata update') "
-                            "via the Red Hat Network web interface.  (Instructions for this are in chapter 6 "
+                            "via the Red Hat Satellite web interface.  (Instructions for this are in chapter 6 "
                             "of the RHN Reference Guide, available from the 'Help' button in the main Red "
-                            "Hat Network web interface.)")
+                            "Hat Network Satellite web interface.)")
 
 # Review Window
 REVIEW_WINDOW           = _("Review Subscription")
 REVIEW_WINDOW_PROMPT    = _("Please review the subscription details below:")
 SUB_NUM                 = _("The installation number %s was activated during "
-                            "this system's initial connection to Red Hat Network.")
+                            "this system's initial connection to Red Hat Satellite.")
 SUB_NUM_RESULT          = _("Subscriptions have been activated for the following "
                             "Red Hat products/services:")
 CHANNELS_TITLE          = _("Software Channel Subscriptions:")
@@ -163,7 +173,7 @@ CHANNELS_SAT_WARNING    = _("Warning: Only installed product listed above will r
                             "to receive updates for additional products, please "
                             "login to your satellite web interface "
                             "and subscribe this system to the appropriate "
-                            "software channels. See Kbase article"
+                            "software channels. See Kbase article "
                             "for more details. "
                             "(http://kbase.redhat.com/faq/docs/DOC-11313)")
 YUM_PLUGIN_WARNING		= _("Warning: yum-rhn-plugin is not present, could not enable it.\n"
@@ -183,9 +193,9 @@ NO_BASE_CHANNEL            = _(
 "to this system's profile in the RHN web interface and subscribe this system "
 "to software channels via the software > software channels tab.")
 SLOTS_TITLE             = _("Service Level:")
-OK_SLOTS                = _("Depending on what RHN Satellite modules are associated with a system, you'll "
+OK_SLOTS                = _("Depending on what Red Hat Satellite modules are associated with a system, you'll "
                             "enjoy different benefits. The following are the "
-                            "RHN Satellite modules associated with this system:")
+                            "Red Hat Satellite modules associated with this system:")
 SLOTS                   =  SLOTS_TITLE + "\n" + OK_SLOTS + "\n%s"
 FAILED_SLOTS            = _("This system was unable to be associated with the "
                             "following RHN module(s) because there were "
@@ -221,12 +231,12 @@ NO_SYS_ENTITLEMENT         = _("This system was unable to be associated with "
 "about this problem. Once you make the "
 "appropriate active subscriptions available in your account, you may browse "
 "to this system's profile in the RHN web interface, delete the profile, and "
-"re-connect this system to Red Hat Network.")
+"re-connect this system to Red Hat Satellite.")
 ACTIVATION_KEY          = _("Universal default activation key detected\n"
                             "A universal default activation key was detected in your account. "
                             "This means that a set of properties (software channel subscriptions, "
                             "package installations, system group memberships, etc.) "
-                            "for your system's connection to RHN Satellite or RHN Proxy"
+                            "for your system's connection to Red Hat Satellite or Red Hat Satellite Proxy"
                             "have been determined by the activation key rather than your "
                             "installation number.  "
                             "You may also refer to the RHN Reference Guide, section 6.4.6 for more details "
@@ -236,12 +246,12 @@ ACTIVATION_KEY          = _("Universal default activation key detected\n"
 # Error Messages.
 FATAL_ERROR                = _("Fatal Error")
 WARNING                    = _("Warning")
-HOSTED_CONNECTION_ERROR    = _("We can't contact the Red Hat Network Server.\n\n"
+HOSTED_CONNECTION_ERROR    = _("We can't contact the Red Hat Satellite.\n\n"
                                "Double check the location provided - is '%s' correct?\n"
                                "If not, you can correct it and try again.\n\n"
                                "Make sure that the network connection on this system is operational.\n\n"
                                "This system will not be able to successfully receive software updates "
-                               "from Red Hat without connecting to a Red Hat Network server")
+                               "from Red Hat without connecting to a Red Hat Satellite server")
 
 BASECHANNELERROR           = _("Architecture: %s, OS Release: %s, OS "
                                "Version: %s")
@@ -253,7 +263,7 @@ SERVER_TOO_OLD             = _("This server doesn't support functionality "
 
 SSL_CERT_ERROR_MSG         = _("<b><span size=\"16000\">Incompatible Certificate File</span></b>\n\n"
                                "The certificate you provided, <b>%s</b>, is not compatible with "
-                               " the Red Hat Network server at <b>%s</b>. You may want to double-check"
+                               " the Red Hat Satellite server at <b>%s</b>. You may want to double-check"
                                " that you have provided a valid certificate file."
                                " Are you sure you have provided the correct certificate, and that"
                                " the certificate file has not been corrupted?\n\n"
@@ -263,8 +273,11 @@ SSL_CERT_EXPIRED           = _("<b><span size=\"12000\">Incompatible Certificate
                                " The certificate is expired. Please ensure you have the correct "
                                " certificate and your system time is correct.")
 
-SSL_CERT_FILE_NOT_FOUND_ERRER = _("Please verify the value of sslCACert in "
-                                  "/etc/sysconfig/rhn/up2date")
+SSL_CERT_FILE_NOT_FOUND_ERRER = _("Please verify the values of sslCACert and serverURL in "
+                                  "/etc/sysconfig/rhn/up2date. You can either make the "
+                                  "serverURL use http instead of https, or you can "
+                                  "download the SSL cert from your Satellite, place it "
+                                  "in /usr/share/rhn, and ensure sslCACert points to it.")
 
 ACT_KEY_USAGE_LIMIT_ERROR = _("Problem registering system.\n\n"
                               "A universal default activation key limits the "
