@@ -1,5 +1,4 @@
 #
-# $Id$
 
 import os
 import sys
@@ -11,7 +10,7 @@ import urllib2
 
 import clientCaps
 import up2dateLog
-import up2dateErrors 
+import up2dateErrors
 import up2dateUtils
 import up2dateAuth
 import urlparse
@@ -41,7 +40,7 @@ class RetryServer(rpclib.Server):
             except xmlrpclib.Fault:
                 raise
             except httplib.BadStatusLine:
-                self.log.log_me("Error: Server Unavailable. Please try later.") 
+                self.log.log_me("Error: Server Unavailable. Please try later.")
                 stdoutMsgCallback(
                       _("Error: Server Unavailable. Please try later."))
                 sys.exit(-1)
@@ -54,7 +53,7 @@ class RetryServer(rpclib.Server):
                     self.serverList.resetServerIndex()
                     raise
 
-                msg = "An error occured talking to %s:\n" % self._host
+                msg = "An error occurred talking to %s:\n" % self._host
                 msg = msg + "%s\n%s\n" % (sys.exc_type, sys.exc_value)
                 msg = msg + "Trying the next serverURL: %s\n" % self.serverList.server()
                 self.log.log_me(msg)
@@ -80,18 +79,18 @@ class RetryServer(rpclib.Server):
             break
         return ret
 
-    
+
     def __getattr__(self, name):
         # magic method dispatcher
         return rpclib.xmlrpclib._Method(self._request1, name)
-                
+
 
 # uh, yeah, this could be an iterator, but we need it to work on 1.5 as well
 class ServerList:
     def __init__(self, serverlist=[]):
         self.serverList = serverlist
         self.index = 0
-        
+
     def server(self):
         self.serverurl = self.serverList[self.index]
         return self.serverurl
@@ -107,7 +106,7 @@ class ServerList:
         self.index = 0
 
 
-def getServer(refreshCallback=None, serverOverride=None):
+def getServer(refreshCallback=None, serverOverride=None, timeout=None):
     log = up2dateLog.initLog()
     cfg = config.initUp2dateConfig()
 
@@ -151,11 +150,12 @@ def getServer(refreshCallback=None, serverOverride=None):
                     refreshCallback=refreshCallback,
                     proxy=proxyHost,
                     username=proxyUser,
-                    password=proxyPassword)
+                    password=proxyPassword,
+                    timeout=timeout)
     s.addServerList(serverList)
 
     s.add_header("X-Up2date-Version", up2dateUtils.version())
-    
+
     if lang:
         s.setlang(lang)
 
@@ -198,7 +198,7 @@ def doCall(method, *args, **kwargs):
 
     while 1:
         failure = 0
-        ret = None        
+        ret = None
         try:
             ret = method(*args, **kwargs)
         except KeyboardInterrupt:
@@ -216,7 +216,7 @@ def doCall(method, *args, **kwargs):
             else:
                 failure = 1
         except httplib.IncompleteRead:
-            print "httplib.IncompleteRead" 
+            print "httplib.IncompleteRead"
             raise up2dateErrors.CommunicationError("httplib.IncompleteRead"), None, sys.exc_info()[2]
 
         except urllib2.HTTPError, e:
@@ -226,9 +226,9 @@ def doCall(method, *args, **kwargs):
             msg = msg + "Error Message: %s\n" % e.msg
             log.log_me(msg)
             raise up2dateErrors.CommunicationError(msg), None, sys.exc_info()[2]
-        
+
         except xmlrpclib.ProtocolError, e:
-            
+
             log.log_me("A protocol error occurred: %s , attempt #%s," % (
                 e.errmsg, attempt_count))
             if e.errcode == 404:
@@ -262,7 +262,7 @@ def doCall(method, *args, **kwargs):
                     pkg = args[0]
                 else:
                     pkg=args[1]
-                    
+
                 if type(pkg) == type([]):
                     pkgName = "%s-%s-%s.%s" % (pkg[0], pkg[1], pkg[2], pkg[4])
                 else:
@@ -270,13 +270,13 @@ def doCall(method, *args, **kwargs):
                 msg = "File Not Found: %s\n%s" % (pkgName, errMsg)
                 log.log_me(msg)
                 raise up2dateErrors.FileNotFoundError(msg), None, sys.exc_info()[2]
-                
+
             if not reset:
                 if attempt_count >= attempts:
                     raise up2dateErrors.CommunicationError(e.errmsg), None, sys.exc_info()[2]
                 else:
                     failure = 1
-            
+
         except xmlrpclib.ResponseError:
             raise up2dateErrors.CommunicationError(
                 "Broken response from the server."), None, sys.exc_info()[2]
@@ -291,9 +291,9 @@ def doCall(method, *args, **kwargs):
             # rest for five seconds before trying again
             time.sleep(5)
             attempt_count = attempt_count + 1
-        
+
         if attempt_count > attempts:
             raise up2dateErrors.CommunicationError("The data returned from the server was incomplete")
 
     return ret
-    
+
